ReceivedNotification class

Model for received notification

Constructors

ReceivedNotification({required int id, required String title, required String body, required String payload})

Properties

body → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
payload → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited